ICACCSRResponseStatusCode

Enum ICACCSRResponseStatusCode 

#[repr(u8)]
pub enum ICACCSRResponseStatusCode { Ok = 0, Busy = 1, Pakeparametererror = 2, Windownotopen = 3, Vidnotverified = 4, Invalidadministratorfabricindex = 5, }

Variants



Ok = 0

No error



Busy = 1

Could not be completed because another commissioning is in progress



Pakeparametererror = 2

Provided PAKE parameters were incorrectly formatted or otherwise invalid



Windownotopen = 3

The Joint Commissioning Method commissioning window is not currently open



Vidnotverified = 4

ICACCSRRequest command has been invoked by a peer against which Fabric Table VID Verification hasn’t been executed



Invalidadministratorfabricindex = 5

OpenJointCommissioningWindow command has been invoked but the AdministratorFabricIndex field has the value of null

Implementations

Source

impl ICACCSRResponseStatusCode

pub fn from_u8(value: u8) -> Option<Self>

Convert from u8 value

pub fn to_u8(self) -> u8

Convert to u8 value